using UnityEngine;
using System;
using System.Collections;

// This class plays FPS animation and synchronizes animation to remote clients
public class AnimationSynchronizer : MonoBehaviour {
	
	public Animation anim; // Animation of the hero (for remote instances)
	public Animation fpsAnim; // Animation of the fps hands model (for local instances)
	
	public enum BaseAnimationState {
		Idle,
		RunForward,
		RunBackward
	}
	

	
	private BaseAnimationState baseState = BaseAnimationState.Idle; // Base layer state for moving, idle, jumping
	
	// We call it on remote player model to start receiving anim messages
	public void StartReceivingAnimation() {
		InitAnimations();
		UpdateAnimation();
	}
	
	// Initializing animations parameters
	private void InitAnimations() {
		anim["Idle"].wrapMode = WrapMode.Loop;
		anim["Idle"].blendMode = AnimationBlendMode.Additive;
		anim["Idle"].layer = 1;
			
		anim["RunForward"].wrapMode = WrapMode.Loop;
		anim["RunForward"].blendMode = AnimationBlendMode.Additive;
		anim["RunForward"].layer = 1;
			
		anim["RunBackward"].wrapMode = WrapMode.Loop;
		anim["RunBackward"].blendMode = AnimationBlendMode.Additive;
		anim["RunBackward"].layer = 1;
				
	
			
	}
	
	// Updating played animation based on state
	private void UpdateAnimation() {
		if (baseState == BaseAnimationState.Idle) {
			if (!anim.IsPlaying("Idle")) {
				anim.Play("Idle");
			}
		}
		
		if (baseState == BaseAnimationState.RunForward) {
			if (!anim.IsPlaying("RunForward")) {
				anim.Play("RunForward");
			}
		}
		
		if (baseState == BaseAnimationState.RunBackward) {
			if (!anim.IsPlaying("RunBackward")) {
				anim.Play("RunBackward");
			}
		}
				
	
					
	}
	
	


	
	// Updating first state from server
	public void RemoteStateUpdate(string message) {
		BaseAnimationState state = (BaseAnimationState)Enum.Parse(typeof(AnimationSynchronizer.BaseAnimationState), message);
		this.baseState = state;
		UpdateAnimation();
	}	
	
	// Settin first state
	void SetAnimationState(BaseAnimationState state) {
		if (state!=this.baseState) {
			this.baseState = state;
			NetworkManager.Instance.SendAnimationState(state.ToString(), 0);
		}
	}
	
	public void PlayIdle() {
		SetAnimationState(BaseAnimationState.Idle);
	}
	
	public void PlayRunForward() {
		SetAnimationState(BaseAnimationState.RunForward);
	}
	
	public void PlayRunBackward() {
		SetAnimationState(BaseAnimationState.RunBackward);
	}
		

		
}
