
using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

// Spawns player and items objects, stores them in collections and provides access to them
public class PlayerManager : MonoBehaviour {
	
	public GameObject enemyPrefab;
	public GameObject playerPrefab;
	private GameObject playerObj;
	
	private static PlayerManager instance;
	public static PlayerManager Instance {
		get {
			return instance;
		}
	}
	public GameObject GetPlayerObject() {
		return playerObj;
	}
	
	private Dictionary<int, NetworkTransformReceiver> recipients = new Dictionary<int, NetworkTransformReceiver>();
	private Dictionary<int, GameObject> items = new Dictionary<int, GameObject>();
		
	void Awake() {
		instance = this;
	}
	
	public void RemoveItem(int id) {
		if (items.ContainsKey(id)) {
			Destroy(items[id]);
			items.Remove(id);
		}
	}

	public void SpawnPlayer(NetworkTransform ntransform, string name, int score) {
		if (Camera.main!=null) {
			Destroy(Camera.main.gameObject);
		}
	
		playerObj = GameObject.Instantiate(playerPrefab) as GameObject;
		playerObj.transform.position = ntransform.Position;
		playerObj.transform.localEulerAngles = ntransform.AngleRotationFPS;
		playerObj.SendMessage("StartSendTransform");
				
		PlayerScore.Instance.SetScore(name, score);
	}
	
	public void SpawnEnemy(int id, NetworkTransform ntransform, string name, int score) {
		GameObject playerObj = GameObject.Instantiate(enemyPrefab) as GameObject;
		playerObj.transform.position = ntransform.Position;
		playerObj.transform.localEulerAngles = ntransform.AngleRotationFPS;
		AnimationSynchronizer animator = playerObj.GetComponent<AnimationSynchronizer>();
		animator.StartReceivingAnimation();
				
		PlayerScore.Instance.SetScore(name, score);
		
		Enemy enemy = playerObj.GetComponent<Enemy>();
		enemy.Init(name);
		
		recipients[id] = playerObj.GetComponent<NetworkTransformReceiver>();
	}
	
	public NetworkTransformReceiver GetRecipient(int id) {
		if (recipients.ContainsKey(id)) {
			return recipients[id];
		}
		return null;
	}
	

	
	public void DestroyEnemy(int id) {
		NetworkTransformReceiver rec = GetRecipient(id);
		if (rec == null) return;
		Destroy(rec.gameObject);
		recipients.Remove(id);
	}
	
	public void SyncAnimation(int id, string msg, int layer) {
		NetworkTransformReceiver rec = GetRecipient(id);
		
		if (rec == null) return;
		
		if (layer == 0) {
			rec.GetComponent<AnimationSynchronizer>().RemoteStateUpdate(msg);
		}
		
	}
	

	

		

	
	
}

